import React, {Component} from 'react'
import PropTypes from 'prop-types'
import { Form, Row, Col, Input, InputNumber } from 'antd'
import { formRule } from '@/utils/option.js'
import TransferForm from '../transferform'
// import Utils from '@/utils/utils.js'
import './index.scss'

class GroupForm extends Component {
  static propTpyes = {
    dict: PropTypes.object,     // 字典项
    group: PropTypes.object,    // 当前分组
    groups: PropTypes.array,    // 所有分组
    inputSubmit: PropTypes.any  // 回车提交事件
  }

  state = {
    source: null,
    selectds: null,
    default: null
  }

  UNSAFE_componentWillMount () {
    const { groups, group } = this.props
    let defaultgroup = groups.filter(item => item.isDefault)[0]
    let _source = defaultgroup.sublist.filter(item => !item.origin)
    let _selectds = group.sublist.map(item => item.uuid )

    _source = [..._source, ...group.sublist]

    this.setState({
      source: _source,
      selectds: _selectds,
    })
  }

  handleConfirm = () => {
    const { groups, group } = this.props
    let defaultgroup = groups.filter(item => item.isDefault)[0]

    // 表单提交时检查输入值是否正确
    return new Promise((resolve, reject) => {
      this.props.form.validateFieldsAndScroll((err, values) => {
        if (!err) {
          values.uuid = group.uuid

          if (group.isDefault) {
            values.isDefault = true
            values.sublist = group.sublist
            
            resolve(values)
          } else {
            let targetKeys = this.refs['fields-transfer'].state.targetKeys
            let defaultlist = this.state.source.filter(item => !targetKeys.includes(item.uuid))

            values.sublist = targetKeys.map(item => {
              return this.state.source.filter(cell => cell.uuid === item)[0]
            })

            resolve({
              default: {...defaultgroup, sublist: defaultlist},
              target: values
            })
          }
        } else {
          reject(err)
        }
      })
    })
  }

  handleSubmit = (e) => {
    e.preventDefault()

    if (this.props.inputSubmit) {
      this.props.inputSubmit()
    }
  }

  render() {
    const { group, groups } = this.props
    const { getFieldDecorator } = this.props.form

    const formItemLayout = {
      labelCol: {
        xs: { span: 24 },
        sm: { span: 8 }
      },
      wrapperCol: {
        xs: { span: 24 },
        sm: { span: 16 }
      }
    }
    return (
      <Form {...formItemLayout} className="ant-advanced-search-form modal-setting-form">
        <Row gutter={24}>
          <Col span={12}>
            <Form.Item label="分组名称">
              {getFieldDecorator('label', {
                initialValue: group.label,
                rules: [
                  {
                    required: true,
                    message: this.props.dict['form.required.input'] + '分组名称!'
                  },
                  {
                    max: formRule.input.max,
                    message: formRule.input.message
                  }
                ]
              })(<Input placeholder="" autoComplete="off" onPressEnter={this.handleSubmit} />)}
            </Form.Item>
          </Col>
          <Col span={12}>
            <Form.Item label="排序">
              {getFieldDecorator('sort', {
                initialValue: group.hasOwnProperty('sort') ? group.sort : groups.length
              })(<InputNumber min={0} max={100} precision={0} />)}
            </Form.Item>
          </Col>
          {!group.isDefault ? <Col span={24}>
            <TransferForm fields={this.state.source} ref="fields-transfer" selected={this.state.selectds}/>
          </Col> : null}
        </Row>
      </Form>
    )
  }
}

export default Form.create()(GroupForm)